package com.inspect.exec.mapper;

import com.inspect.exec.domain.SilenceTaskPointExecRecord;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface SilenceTaskPointExecRecordMapper {
    SilenceTaskPointExecRecord selectSilenceTaskPointExecRecordByPointId(Long pointId);

    List<SilenceTaskPointExecRecord> selectSilenceTaskPointExecRecordList(SilenceTaskPointExecRecord record);

    int insertSilenceTaskPointExecRecord(SilenceTaskPointExecRecord record);

    int updateSilenceTaskPointExecRecord(SilenceTaskPointExecRecord record);

    int deleteSilenceTaskPointExecRecordByPointId(Long pointId);

    int deleteSilenceTaskPointExecRecordByPointIds(Long[] pointIds);
}
